### Squads

All Types return a [ValueDict](https://github.com/cree-py/pynite/blob/master/docs/main.md#valuedict)

| Name | Description |
|------|-------------|
| squads.trn_rating | The Tracker Network Rating. |
| squads.score | The Score finishes. | ValueDict |
| squads.top1 | The Victory Royales finishes. |
| squads.top3 | The number of Top 3 finishes. |
| squads.top5 | The number of Top 5 finishes. |
| squads.top6 | The number of Top 6 finishes. |
| squads.top10 | The number of Top 10 finishes. |
| squads.top12 | The number of Top 12 finishes. |
| squads.top25 | The number of Top 25 finishes. |
| squads.kd | The Kill to Death ratio in squads. |
| squads.matches | The number of matches played. |
| squads.kills | The number of kills in squads.
| squads.minutes_played | The number of minutes played in squads.
| squads.kpm | The average number of kills per minute. |
| squads.kpg | The average number of kills per game. |
| squads.avg_time_played | The average amount of time for each match. |
| squads.score_per_match | The average score per match played |
| squads.score_per_min | The average score per minute played |
